*** Stata MP 13.1 
*** Replication Code for Figure 1 and Tables 1-4
*** Strategic Anticipation of En Banc Review in the U.S. Court of Appeals
*** Rachael K. Hinkle
*** 50 Law & Society Review (2) 383-414

use "Hinkle.LSR2016.dta", clear
drop if cir_align == .
drop if au_tenure == .
keep dv3 any_cite cir_align pan_align sim_percentile_uq same_au prevCited cited_dissent cited_per_curiam cited_en_banc cited_elite_au cited_incir_vitality cited_incir_tot_cites cited_incir_tot_trt cited_prec_age cited_prec_age2 ln_cited_word_count cited_pr_quoted au_tenure citing_dissent citing_concur ln_citing_word_count citing_cir_num_judges citing_year ln_citing_in_cir_choice_set citing_caseload citing_caseID

*** Figure 1 ***
kdensity sim_percentile_uq if any_cite ==1, xline(20 80, lcolor(black) lpattern(dash))  xline(50, lcolor(black) ) xtitle(Similarity Percentile, col(black)) title(Similarity Percentile for Cited Precedents, color(black)) xsize(6) ysize(4) graphregion(lcolor(black) lwidth(thick)) graphregion(fcolor(white))

*** Table 1 ***
sum cir_align pan_align sim_percentile_uq cited_incir_vitality cited_incir_tot_cites cited_incir_tot_trt cited_prec_age ln_cited_word_count cited_pr_quoted au_tenure ln_citing_word_count citing_cir_num_judges citing_year ln_citing_in_cir_choice_set citing_caseload if sim_percentile_uq > 50, detail
tab same_au if sim_percentile_uq > 50
tab prevCited if sim_percentile_uq > 50 
tab cited_dissent if sim_percentile_uq > 50 
tab cited_per_curiam if sim_percentile_uq > 50
tab cited_en_banc if sim_percentile_uq > 50 
tab cited_elite_au if sim_percentile_uq > 50 
tab citing_dissent if sim_percentile_uq > 50
tab citing_concur if sim_percentile_uq > 50

*** Table 2 ***
probit any_cite c.cir_align##c.pan_align sim_percentile_uq same_au prevCited cited_dissent cited_per_curiam cited_en_banc cited_elite_au cited_incir_vitality cited_incir_tot_cites cited_incir_tot_trt cited_prec_age cited_prec_age2 ln_cited_word_count cited_pr_quoted au_tenure citing_dissent citing_concur ln_citing_word_count citing_cir_num_judges citing_year ln_citing_in_cir_choice_set citing_caseload if sim_percentile_uq > 50,  robust cluster(citing_caseID)
beep

**Computing marginal effects requires considerable computing power
*margins, dydx(cir_align pan_align) at(cir_align=(-.5(.1).5) pan_align=(-.6(.1).6)  sim_percentile_uq=75 same_au=0 prevCited=0 cited_dissent=0 cited_per_curiam=0 cited_en_banc=0 cited_elite_au=0 cited_incir_vitality=0 cited_incir_tot_cites=2 cited_incir_tot_trt=0 cited_prec_age=16  ln_cited_word_count=8.03 cited_pr_quoted=.08 au_tenure=12.67 citing_dissent=0 citing_concur=0 ln_citing_word_count=8.15 citing_cir_num_judges=12 ln_citing_in_cir_choice_set=7.17 citing_caseload=440 citing_year = 2003)
** Predicted prob of citation at medians 
*margins, at(cir_align=(.225) pan_align=(.135 ) sim_percentile_uq=75 same_au=0 prevCited=0 cited_dissent=0 cited_per_curiam=0 cited_en_banc=0 cited_elite_au=0 cited_incir_vitality=0 cited_incir_tot_cites=2 cited_incir_tot_trt=0 cited_prec_age=16 cited_prec_age2=256  ln_cited_word_count=8.03 cited_pr_quoted=.08 au_tenure=12.67 citing_dissent=0 citing_concur=0 ln_citing_word_count=8.15 citing_cir_num_judges=12 ln_citing_in_cir_choice_set=7.17 citing_caseload=440 citing_year = 2003)
** Predicted prob of citation at medians for cited precedents
*margins, at(cir_align=(.225) pan_align=(.135 )  sim_percentile_uq=85 same_au=0 prevCited=0 cited_dissent=0 cited_per_curiam=0 cited_en_banc=0 cited_elite_au=0 cited_incir_vitality=0 cited_incir_tot_cites=3 cited_incir_tot_trt=0 cited_prec_age=5 cited_prec_age2=25 ln_cited_word_count=8.26 cited_pr_quoted=.09 au_tenure=12 citing_dissent=0 citing_concur=0 ln_citing_word_count=8.34 citing_cir_num_judges=11 citing_year=2003)
** Predicted prob citation at medians for cited precedents 
*margins, at(cir_align=(-.5165 .225 .5165) pan_align=(-.65 .135 .65)  sim_percentile_uq=95 same_au=0 prevCited=0 cited_dissent=0 cited_per_curiam=0 cited_en_banc=0 cited_elite_au=0 cited_incir_vitality=0 cited_incir_tot_cites=3 cited_incir_tot_trt=0 cited_prec_age=5 cited_prec_age2=25 ln_cited_word_count=8.26 cited_pr_quoted=.09 au_tenure=12 citing_dissent=0 citing_concur=0 ln_citing_word_count=8.34 citing_cir_num_judges=11 citing_year=2003)
 

*** Table 3 ***
mprobit dv3  c.cir_align##c.pan_align sim_percentile_uq same_au prevCited cited_dissent cited_per_curiam cited_en_banc cited_elite_au cited_incir_vitality cited_incir_tot_cites cited_incir_tot_trt cited_prec_age cited_prec_age2 ln_cited_word_count cited_pr_quoted au_tenure citing_dissent citing_concur ln_citing_word_count citing_cir_num_judges citing_year ,  robust cluster(citing_caseID) 

*margins, predict(outcome(-1)) at(cir_align=(.225) pan_align=(.135 )  sim_percentile_uq=85 same_au=0 prevCited=0 cited_dissent=0 cited_per_curiam=0 cited_en_banc=0 cited_elite_au=0 cited_incir_vitality=0 cited_incir_tot_cites=3 cited_incir_tot_trt=0 cited_prec_age=5 cited_prec_age2=25 ln_cited_word_count=8.26 cited_pr_quoted=.09 au_tenure=12 citing_dissent=0 citing_concur=0 ln_citing_word_count=8.34 citing_cir_num_judges=11 citing_year=2003)
*margins, predict(outcome(-1)) at(cir_align=(.225) pan_align=(.135 )  sim_percentile_uq=99 same_au=0 prevCited=0 cited_dissent=0 cited_per_curiam=0 cited_en_banc=0 cited_elite_au=0 cited_incir_vitality=0 cited_incir_tot_cites=3 cited_incir_tot_trt=0 cited_prec_age=5 cited_prec_age2=25 ln_cited_word_count=8.26 cited_pr_quoted=.09 au_tenure=12 citing_dissent=0 citing_concur=0 ln_citing_word_count=8.34 citing_cir_num_judges=11 citing_year=2003)
*margins, predict(outcome(-1)) at(cir_align=(-.5 -.4 -.3 -.2 -.1 0 .1 .225 .3 .4 .5) pan_align=(-.6 -.5 -.4 -.3 -.2 -.1 0 .135 .2 .3 .4 .5 .6)  sim_percentile_uq=95 same_au=0 prevCited=0 cited_dissent=0 cited_per_curiam=0 cited_en_banc=0 cited_elite_au=0 cited_incir_vitality=0 cited_incir_tot_cites=3 cited_incir_tot_trt=0 cited_prec_age=5  ln_cited_word_count=8.26 cited_pr_quoted=.09 au_tenure=12 citing_dissent=0 citing_concur=0 ln_citing_word_count=8.34 citing_cir_num_judges=11 citing_year=2003)


*** Table 4 ***

** Similarity % > 20 **
probit any_cite c.cir_align##c.pan_align sim_percentile_uq same_au prevCited cited_dissent cited_per_curiam cited_en_banc cited_elite_au cited_incir_vitality cited_incir_tot_cites cited_incir_tot_trt cited_prec_age cited_prec_age2 ln_cited_word_count cited_pr_quoted au_tenure citing_dissent citing_concur ln_citing_word_count citing_cir_num_judges citing_year ln_citing_in_cir_choice_set citing_caseload if sim_percentile_uq > 20,  robust cluster(citing_caseID)

** Similarity % > 80 **
probit any_cite c.cir_align##c.pan_align sim_percentile_uq same_au prevCited cited_dissent cited_per_curiam cited_en_banc cited_elite_au cited_incir_vitality cited_incir_tot_cites cited_incir_tot_trt cited_prec_age cited_prec_age2 ln_cited_word_count cited_pr_quoted au_tenure citing_dissent citing_concur ln_citing_word_count citing_cir_num_judges citing_year ln_citing_in_cir_choice_set citing_caseload  if sim_percentile_uq > 80,  robust cluster(citing_caseID)



